@@ -61,7 +61,7 @@ except ImportError:
         return _convert(node_or_string)
 
 
-__version__ = '1.2.1'
+__version__ = '1.2.2'
 __all__ = ['Client', 'Model', 'Record', 'RecordList', 'Service',
            'format_exception', 'read_config']
 
@@ -810,8 +810,6 @@ class Client(object):
         except (TypeError, Fault):
             return False
 
-        return self.model(obj).access(mode=mode)
-
     def __getattr__(self, method):
         if not method.islower():
             rv = self.model(lowercase(method))
@@ -894,19 +892,19 @@ class Model(object):
         Otherwise, the return value is a :class:`RecordList`.
         """
         context = kwargs.pop('context', None)
-        assert issearchdomain(domain) or not (params or kwargs)
-        ids = domain
-        if isinstance(ids, int_types):
-            return Record(self, ids, context=context)
+        if isinstance(domain, int_types):
+            assert not params and not kwargs
+            return Record(self, domain, context=context)
         if issearchdomain(domain):
             params = searchargs((domain,) + params, kwargs, context)
-            ids = self._execute('search', *params)
+            domain = self._execute('search', *params)
             # Ignore extra keyword arguments
             for item in kwargs.items():
                 print('Ignoring: %s = %r' % item)
-        return RecordList(self, ids, context=context)
-
-    # alias
+        else:
+            assert not params and not kwargs
+        return RecordList(self, domain, context=context)
+    # undocumented alias
     get = browse
 
     def create(self, values, context=None):
@@ -915,6 +913,7 @@ class Model(object):
         The argument `values` is a dictionary of values which are used to
         create the record.  The newly created :class:`Record` is returned.
         """
+        values = self._unbrowse_values(values)
         new_id = self._execute('create', values, context=context)
         return Record(self, new_id, context=context)
 
@@ -942,9 +941,29 @@ class Model(object):
             elif field_type in ('one2many', 'many2many'):
                 rel_model = get_model(field['relation'])
                 value = RecordList(rel_model, value, context=context)
+            elif field_type == 'reference':
+                res_model, res_id = value.split(',')
+                value = Record(get_model(res_model), int(res_id))
             new_values[key] = value
         return new_values
 
+    def _unbrowse_values(self, values):
+        """Unwrap the id of Record and RecordList."""
+        new_values = values.copy()
+        for key, value in values.items():
+            field_type = self._fields[key]['type']
+            if isinstance(value, (Record, RecordList)):
+                if field_type == 'reference':
+                    new_values[key] = '%s,%s' % (value._model_name, value.id)
+                else:
+                    new_values[key] = value = value.id
+            if field_type in ('one2many', 'many2many'):
+                if not value:
+                    new_values[key] = [(6, 0, [])]
+                elif isinstance(value[0], (int, long)):
+                    new_values[key] = [(6, 0, value)]
+        return new_values
+
     def __getattr__(self, attr):
         if attr in ('_keys', '_fields'):
             self.__dict__[attr] = rv = getattr(self, '_get' + attr)()
@@ -1020,6 +1039,14 @@ class RecordList(object):
                     return [RecordList(rel_model, v) for v in values]
         return values
 
+    def write(self, values, context=None):
+        """Write the `values` in the :class:`RecordList`."""
+        if context is None and self._context:
+            context = self._context
+        values = self._model._unbrowse_values(values)
+        rv = self._model._execute('write', self.id, values, context=context)
+        return rv
+
     def __getitem__(self, key):
         cls = isinstance(key, slice) and RecordList or Record
         return cls(self._model, self._idnames[key], context=self._context)
@@ -1142,13 +1169,11 @@ class Record(object):
         """Write the `values` in the :class:`Record`."""
         if context is None and self._context:
             context = self._context
+        values = self._model._unbrowse_values(values)
         rv = self._model._execute('write', [self.id], values, context=context)
         self._clear_cache()
         return rv
 
-    # alias
-    update = write
-
     def unlink(self, context=None):
         """Delete the current :class:`Record` from the database."""
         if context is None and self._context:
@@ -1165,6 +1190,8 @@ class Record(object):
         """
         if context is None and self._context:
             context = self._context
+        if default:
+            default = self._model._unbrowse_values(default)
         new_id = self._model._execute('copy', self.id, default, context=context)
         return Record(self._model, new_id)
 
