@@ -328,6 +328,27 @@ class TestModel(TestCase):
         self.assertCalls()
         self.assertOutput('')
 
+    def test_create(self):
+        FooBar = self.model('foo.bar')
+
+        record42 = FooBar.browse(42)
+        recordlist42 = FooBar.browse([4, 2])
+
+        FooBar.create({'spam': 42})
+        FooBar.create({'spam': record42})
+        FooBar.create({'spam': recordlist42})
+        FooBar._execute('create', {'spam': 42})
+        FooBar.create({})
+        self.assertCalls(
+            OBJ('foo.bar', 'fields_get'),
+            OBJ('foo.bar', 'create', {'spam': 42}),
+            OBJ('foo.bar', 'create', {'spam': 42}),
+            OBJ('foo.bar', 'create', {'spam': [4, 2]}),
+            OBJ('foo.bar', 'create', {'spam': 42}),
+            OBJ('foo.bar', 'create', {}),
+        )
+        self.assertOutput('')
+
     def test_method(self, method_name='method', single_id=True):
         FooBar = self.model('foo.bar')
         FooBar_method = getattr(FooBar, method_name)
@@ -349,7 +370,7 @@ class TestModel(TestCase):
         self.assertOutput('')
 
     def test_standard_methods(self):
-        for method in 'write create copy unlink'.split():
+        for method in 'write', 'copy', 'unlink':
             self.test_method(method)
 
         self.test_method('perm_read', single_id=False)
@@ -383,6 +404,54 @@ class TestRecord(TestCase):
         )
         self.assertOutput('')
 
+    def test_write(self):
+        records = self.model('foo.bar').browse([13, 17])
+        rec = self.model('foo.bar').browse(42)
+
+        rec.write({})
+        rec.write({'spam': 42})
+        rec.write({'spam': rec})
+        rec.write({'spam': records})
+        records.write({})
+        records.write({'spam': 42})
+        records.write({'spam': rec})
+        records.write({'spam': records})
+        self.assertCalls(
+            OBJ('foo.bar', 'write', [42], {}),
+            OBJ('foo.bar', 'fields_get_keys'),
+            OBJ('foo.bar', 'fields_get'),
+            OBJ('foo.bar', 'write', [42], {'spam': 42}),
+            OBJ('foo.bar', 'write', [42], {'spam': 42}),
+            OBJ('foo.bar', 'write', [42], {'spam': [13, 17]}),
+            OBJ('foo.bar', 'write', [13, 17], {}),
+            OBJ('foo.bar', 'write', [13, 17], {'spam': 42}),
+            OBJ('foo.bar', 'write', [13, 17], {'spam': 42}),
+            OBJ('foo.bar', 'write', [13, 17], {'spam': [13, 17]}),
+        )
+        self.assertOutput('')
+
+    def test_copy(self):
+        rec = self.model('foo.bar').browse(42)
+        records = self.model('foo.bar').browse([13, 17])
+
+        recopy = rec.copy()
+        self.assertIsInstance(recopy, erppeek.Record)
+        self.assertEqual(recopy.id, sentinel.OTHER)
+
+        rec.copy({'spam': 42})
+        rec.copy({'spam': rec})
+        rec.copy({'spam': records})
+        rec.copy({})
+        self.assertCalls(
+            OBJ('foo.bar', 'copy', 42, None),
+            OBJ('foo.bar', 'fields_get'),
+            OBJ('foo.bar', 'copy', 42, {'spam': 42}),
+            OBJ('foo.bar', 'copy', 42, {'spam': 42}),
+            OBJ('foo.bar', 'copy', 42, {'spam': [13, 17]}),
+            OBJ('foo.bar', 'copy', 42, {}),
+        )
+        self.assertOutput('')
+
     def test_method(self, method_name='method'):
         records = self.model('foo.bar').browse([13, 17])
         rec = self.model('foo.bar').browse(42)
@@ -429,6 +498,10 @@ class TestRecord(TestCase):
         records = self.model('foo.bar').browse([13, 17])
         rec = self.model('foo.bar').browse(42)
 
+        # attribute "id" is always present
+        self.assertEqual(rec.id, 42)
+        self.assertEqual(records.id, [13, 17])
+
         # existing fields can be read as attributes
         # attribute is writable on the Record object only
         self.assertFalse(callable(rec.message))
@@ -443,14 +516,18 @@ class TestRecord(TestCase):
         self.assertCalls(
             OBJ('foo.bar', 'fields_get_keys'),
             OBJ('foo.bar', 'read', 42, ['message']),
+            OBJ('foo.bar', 'fields_get'),
             OBJ('foo.bar', 'write', [42], {'message': 'one giant leap for mankind'}),
             OBJ('foo.bar', 'read', 42, ['message']),
             OBJ('foo.bar', 'read', [13, 17], ['message']),
-            OBJ('foo.bar', 'fields_get'),
             OBJ('foo.bar', 'missingattr', [42]),
             OBJ('foo.bar', 'missingattr', [13, 17]),
         )
 
+        # attribute "id" is never writable
+        self.assertRaises(AttributeError, setattr, rec, 'id', 42)
+        self.assertRaises(AttributeError, setattr, records, 'id', 42)
+
         # `setattr` not allowed (except for existing fields on Record object)
         self.assertRaises(AttributeError, setattr, rec, 'missingattr', 42)
         self.assertRaises(AttributeError, setattr, records, 'message', 'one')
